@@ -21,6 +21,8 @@
 #include "DualwordRT.h"
 #include "global.h"
 
+using langList = QList<QPair<QString, QString>>;
+
 MainWindow::MainWindow(QWidget *p) : QMainWindow(p), scene(), rand(RT_DMIN,RT_DMAX), msg(""){
 
     translator = new QTranslator(this);
@@ -42,22 +44,19 @@ MainWindow::MainWindow(QWidget *p) : QMainWindow(p), scene(), rand(RT_DMIN,RT_DM
     connect(toggle,SIGNAL(triggered()),this,SLOT(fullScreen()));
     menu->addAction(toggle);
 
-    QList<QPair<QString, QString>> lang;
-    lang << QPair<QString, QString>("English", "en") << QPair<QString, QString>("Deutsch", "de")
-         << QPair<QString, QString>("Русский", "ru");
+    langList lang = {{"English", "en"}, {"Deutsch", "de"}, {"Русский", "ru"}};
     auto lm = menu->addMenu(tr("Languages"));
     lm->setToolTip(tr("New language will be available after a restart."));
-    foreach (const auto& str, lang){
-        auto act = new QAction(str.first);
-        if(slang == str.second){
+    for(const auto& [lname, lcode] : lang) {
+        auto act = new QAction(lname);
+        if(slang == lcode){
             QFont font;
             font.setBold(true);
             act->setFont(font);
         }
-        connect(act, QOverload<bool>::of(&QAction::triggered), [=](bool b){
-            Q_UNUSED(b);
+        connect(act, &QAction::triggered, [=](){
             QSettings settings;
-            settings.setValue("lang", str.second);
+            settings.setValue("lang", lcode);
         });
         lm->addAction(act);
     }
@@ -67,7 +66,6 @@ MainWindow::MainWindow(QWidget *p) : QMainWindow(p), scene(), rand(RT_DMIN,RT_DM
 	connect(about,SIGNAL(triggered()),this,SLOT(showAbout()));
 	setCentralWidget(&glview);
     stateNew();
-
 }
 
 MainWindow::~MainWindow() {
@@ -75,7 +73,8 @@ MainWindow::~MainWindow() {
 }
 
 void MainWindow::init(){
-
+    timeout.reset(new Timer());
+    timer.reset(new Timer());
 }
 
 void MainWindow::fullScreen() {
@@ -100,20 +99,18 @@ void MainWindow::keyPressEvent(QKeyEvent *event) {
 	if (state == State::new1){
 		stateWait();
 	}else if (state == State::wait){
-		if( event->key() == Qt::Key_Q){
+        if( event->key() == Qt::Key_Q && !tL.isStopped()){
 			tL.stop();
-		}else  if( event->key() == Qt::Key_P){
+        }else  if( event->key() == Qt::Key_P && !tR.isStopped()){
 			tR.stop();
-		}
-		if(tL.isStopped() & tR.isStopped()) stateDone();
+        }
+        if(tL.isStopped() & tR.isStopped()) stateDone();
 	}else if (state == State::notready){
 		stateNotReady();
 	}
-    QMainWindow::keyPressEvent(event);
 }
 
 void MainWindow::stateNew(){
-	tL=Time(),tR=Time();
 	pause = 0;
 	state = State::new1;
 	scene.printMsg(tr("Press P or Q to start..."));
@@ -122,9 +119,7 @@ void MainWindow::stateNew(){
 void MainWindow::stateWait(){
 	state = State::notready;
 	scene.printMsg(tr("Press 2 buttons (P and Q) when you see a yellow circle..."));
-    timer.reset(new QTimer());
-    timer->setTimerType(Qt::PreciseTimer);
-	timer->setSingleShot(true);
+    timer.reset(new Timer());
     connect(timer.get(), SIGNAL(timeout()), this, SLOT(stateVisual()));
 	pause = rand() * 1000;
 	timer->start(pause);
@@ -133,10 +128,19 @@ void MainWindow::stateWait(){
 void MainWindow::stateVisual(){
 	scene.showCirle();
 	state = State::wait;
+    tL=Time(),tR=Time();
 	tL.start(), tR.start();
+    timeout.reset(new Timer());
+    connect(timeout.get(), &Timer::timeout, [this]{
+        timer->stop();
+        state = State::new1;
+        scene.printMsg(tr("Timeout.\nPress P or Q to continue..."));
+    });
+    timeout->start(RT_TIMEOUT);
 }
 
 void MainWindow::stateDone(){
+    timeout->stop();
 	tL.reset();
 	tR.reset();
 	state = State::new1;
@@ -165,6 +169,7 @@ void MainWindow::stateDone(){
 
 void MainWindow::stateNotReady(){
 	timer->stop();
+    timeout->stop();
 	state = State::new1;
 	scene.printMsg(tr("Error.\nPress P or Q to continue..."));
 }
@@ -173,7 +178,7 @@ void MainWindow::showAbout(){
 	QString str;
 	str.append(qApp->applicationName());
 	str.append(" ").append(qApp->applicationVersion()).append("<br>");
-	str.append("License: GPL v3 <br/>");
+    str.append("License: GPL v3+ (GPL-3.0-or-later)<br/>");
     str.append("Website: <a href='https://github.com/dualword/dualword-rt'>https://github.com/dualword/dualword-rt</a> <br/>");
     str.append("&copy; 2015-2025 Alexander Busorgin <br/>");
 	QMessageBox::about(this, tr("About"), str );
