@@ -20,9 +20,8 @@
 #ifndef MAINWINDOW_H_
 #define MAINWINDOW_H_
 
-#include <memory>
-
 #include "Time.h"
+#include "Timer.h"
 #include "Rnd.h"
 #include "Scene.h"
 #include "View.h"
@@ -48,8 +47,8 @@ public slots:
 	void stateVisual();
 	void contextMenuRequested(QPoint);
 	void showAbout();
-	void init();
-	
+    void init();
+
 private slots:
 	void fullScreen();
 
@@ -63,7 +62,7 @@ private:
 	View glview;
     State state;
     Time tL, tR;
-    QScopedPointer<QTimer> timer;
+    QScopedPointer<Timer> timer, timeout;
 	QMenu  *menu;
     QAction *toggle, *about;
 	int pause;
