@@ -67,5 +67,11 @@ Drücken Sie die Taste P oder Q, um fortzusetzen...</translation>
         <source>New language will be available after a restart.</source>
         <translation>Die neue Sprache wird nach einem Neustart verfügbar sein.</translation>
     </message>
+    <message>
+        <source>Timeout.
+Press P or Q to continue...</source>
+<translation>Zeitüberschreitung.
+Drücken Sie die Taste P oder Q, um fortzusetzen...</translation>
+    </message>
 </context>
 </TS>
