@@ -67,5 +67,11 @@ Press P or Q to continue...</source>
         <source>New language will be available after a restart.</source>
         <translation>Новый язык будет доступен после перезапуска.</translation>
     </message>
+    <message>
+        <source>Timeout.
+Press P or Q to continue...</source>
+<translation>Истекло время ожидания.
+Нажмите P или Q чтобы продолжить...</translation>
+    </message>
 </context>
 </TS>
